@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -563,6 +563,8 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
     public void writeUpdatedDataObject(DataObject object, long timestamp) throws USMException {
         if (LOG.isDebugEnabled())
             LOG.debug(object.getSession() + " Updating " + _contentType.getID());
+        if (LOG.isTraceEnabled())
+            LOG.trace("Updating data object  " + object.toString());
         checkTypeToWrite(object, _contentType.getID());
 
         Map<String, String> parameters = new HashMap<String, String>();
@@ -577,6 +579,12 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
             throw new USMException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER14, "Error on creating request body", e1);
         }
 
+        if (LOG.isTraceEnabled())
+            try {
+                LOG.trace("Updating data object (json data)  " + requestBody.toString(1, 4));
+            } catch (JSONException e1) {
+                // ignore
+            }
         // printTimeValues("Change", requestBody);
         JSONResult result = _ajaxAccess.doPut(
             getOXAjaxAccessPath(),
@@ -589,6 +597,7 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         // XXX Shouldn't we use the timestamp returned from the OX server ?
         object.setTimestamp(timestamp);
         JSONObject o = result.getJSONObject();
+        updateIdForNewException(object, result);
         try {
             JSONObject resultObject = o.getJSONObject(CommonConstants.RESULT_DATA);
             if (resultObject.has(CalendarConstants.CONFLICTS)) {
@@ -657,5 +666,19 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
         }
         return null;
     }
+    
+    private void updateIdForNewException(DataObject object, JSONResult result) {
+        try {
+            JSONObject resultObject = result.getJSONObject().getJSONObject(CommonConstants.RESULT_DATA);
+            if (resultObject.has(CommonConstants.ID)) {
+                String id = resultObject.getString(CommonConstants.ID);
+                if (id.length()>0 && !object.getID().equals(id)) {
+                    object.setID(id);
+                }
+            }
+        } catch (JSONException e) {
+            // ignore any error
+        }
+    }
 
 }
