@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,9 +69,9 @@ public final class USMJSONVersion {
     /**
      * USM JSON versions
      */
-    public static final String VERSION = "7.8.0-10";
+    public static final String VERSION = "7.8.1-9";
 
-    public static final String BUILD_NUMBER = "98e5b5a678ca882029c97db9f8256a01867162bb- 6970";
+    public static final String BUILD_NUMBER = "655b27eeffe5e9ecb8aced544dc10e8f7237cac7- 7004";
 
     public static final String _CLIENT_USM_JSON_VERSION_KEY = "json.Prot.Version";
 
@@ -81,11 +81,13 @@ public final class USMJSONVersion {
 
     public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING = new USMJSONVersion("2.2.0");
     
+    public static final USMJSONVersion SUPPORTS_STANDARD_FOLDER_SWAPPING = new USMJSONVersion("2.3.0");
+    
     public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754 = new USMJSONVersion("2.1.0");
 
     private static final USMJSONVersion _CURRENT_VERSION = _SUPPORTS_FILTERED_OUT_LARGE_OBJECTS_STATUS_CODE;
 
-    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_CONTACT_IMAGE_STREAMING;
+    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_STANDARD_FOLDER_SWAPPING;
 
     private static final List<USMJSONVersion> _supportedVersions = new ArrayList<USMJSONVersion>();
 
@@ -93,6 +95,7 @@ public final class USMJSONVersion {
         if (_supportedVersions.isEmpty()) {
             synchronized (_supportedVersions) {
                 if (_supportedVersions.isEmpty()) {
+                    _supportedVersions.add(SUPPORTS_STANDARD_FOLDER_SWAPPING);
                     _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING);
                     _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754);
                     _supportedVersions.add(SUPPORTS_ATTACHMENT_STREAMING);
@@ -149,6 +152,10 @@ public final class USMJSONVersion {
         return !getUsedVersion(session).isOlder(SUPPORTS_CONTACT_IMAGE_STREAMING.getVersion(), 3);
     }
 
+    public static boolean supportsStandardFolderSwapping(Session session) {
+        return !getUsedVersion(session).isOlder(SUPPORTS_STANDARD_FOLDER_SWAPPING.getVersion(), 3);
+    }
+
     public static Version getUsedVersion(Session session) {
         return Version.fromString(session.getPersistentField(_CLIENT_USM_JSON_VERSION_KEY));
     }
