@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2016 OX Software GmbH
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -742,7 +742,7 @@ public class SessionManagerImpl implements SessionManager {
         }
     }
 
-    public DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws StorageAccessException, USMStorageException {
+    public static DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws StorageAccessException, USMStorageException {
         boolean useModifiedUUID = o.getSession().getUserIdentifier() != o.getParentFolderOwnerID();
         if (oldData != null) {
             DataObject oldObject = oldData.get(o.getID());
@@ -757,8 +757,22 @@ public class SessionManagerImpl implements SessionManager {
             if (newestCachedData == null)
                 newestCachedData = new DataObjectSet(o.getSession().getCachedFolders());
             DataObject cachedFolder = newestCachedData.get(o.getID());
-            if (cachedFolder != null)
+            if (cachedFolder != null) {
+                if (oldData != null) {
+                    DataObject oldFolder = oldData.get(cachedFolder.getUUID());
+                    if (oldFolder != null) {
+                      if (!oldFolder.getID().equals(cachedFolder.getID()) && newestCachedData.get(oldFolder.getID()) != null) {
+                          // we have a swap situation
+                          DataObject swappedFolder = newestCachedData.get(oldFolder.getID());
+                          if (swappedFolder != null && swappedFolder.getUUID() != null) {
+                              o.setUUID(swappedFolder.getUUID());
+                              break;
+                          }
+                      }
+                    }
+                }
                 o.setUUID(cachedFolder.getUUID());
+            }
             break;
         case DefaultContentTypes.MAIL_CODE:
             if (newestCachedData == null)
